OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Ikuslea",
    "Your browser does not support the video tag." : "Zure nabigatzaileak ez du euskarririk video etiketarentzat",
    "View" : "Ikusi",
    "Share" : "Elkarbanatu"
},
"nplurals=2; plural=(n != 1);");
